==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/zh_CN.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "生成备用码时出错",
    "{name} backup codes" : "{name} 备用码",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "下列是您的备用码。备用码无法重复查看，请将其保存或打印存储。",
    "Save backup codes" : "保存备用码",
    "Print backup codes" : "打印备用码",
    "Backup codes have been generated. {used} of {total} codes have been used." : "备用码已生成。备用码 {total} 条中的 {used} 条已被使用。",
    "Regenerate backup codes" : "重新生成备用码",
    "_icon-loading-small_::_generate-backup-codes_" : ["生成备用码"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "如果您重新生成了备用码，旧的代码将自动失效。",
    "Generate backup codes" : "生成备用码",
    "You created two-factor backup codes for your account" : "您已经为账号创建了两步验证的备用码",
    "Second-factor backup codes" : "两步验证备用码",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "您已启用双因素认证但还没有生成备用码。请确保您进行了这一操作以防您不能访问您的第二因素。",
    "Backup code" : "备用码",
    "Use backup code" : "使用备用码",
    "Two factor backup codes" : "双因素备用码",
    "A two-factor auth backup codes provider" : "一个双因素认证备用码提供者",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "在设置双因素认证时使用您保存的其中一个备用码",
    "Submit" : "提交",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "备用码已经生成。已经使用了 {{used}} (共 {{total}}) 个备用码。",
    "Nextcloud backup codes" : "Nextcloud 备用码",
    "activated" : "已激活",
    "updated" : "已更新",
    "mounted" : "已挂载",
    "deactivated" : "已停用",
    "beforeCreate" : "创建前",
    "created" : "已创建",
    "beforeUpdate" : "更新前",
    "beforeDestroy" : "销毁前",
    "destroyed" : "已销毁",
    "beforeMount" : "挂载前"
},
"nplurals=1; plural=0;");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/zh_CN.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "生成备用码时出错",
    "{name} backup codes" : "{name} 备用码",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "下列是您的备用码。备用码无法重复查看，请将其保存或打印存储。",
    "Save backup codes" : "保存备用码",
    "Print backup codes" : "打印备用码",
    "Backup codes have been generated. {used} of {total} codes have been used." : "备用码已生成。备用码 {total} 条中的 {used} 条已被使用。",
    "Regenerate backup codes" : "重新生成备用码",
    "_icon-loading-small_::_generate-backup-codes_" : ["生成备用码"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "如果您重新生成了备用码，旧的代码将自动失效。",
    "Generate backup codes" : "生成备用码",
    "You created two-factor backup codes for your account" : "您已经为账号创建了两步验证的备用码",
    "Second-factor backup codes" : "两步验证备用码",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "您已启用两步验证但还没有生成备用码。当您丢失您的第二因素时，备用码能帮助您恢复对您账号的访问。",
    "Backup code" : "备用码",
    "Use backup code" : "使用备用码",
    "Two factor backup codes" : "两步验证备用码",
    "A two-factor auth backup codes provider" : "一个两步验证备用码提供者",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "在设置两步验证时使用您保存的其中一个备用码",
    "Submit" : "提交",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "备用码已经生成。已经使用了 {{used}} (共 {{total}}) 个备用码。",
    "Nextcloud backup codes" : "Nextcloud 备用码",
    "activated" : "已激活",
    "updated" : "已更新",
    "mounted" : "已挂载",
    "deactivated" : "已停用",
    "beforeCreate" : "创建前",
    "created" : "已创建",
    "beforeUpdate" : "更新前",
    "beforeDestroy" : "销毁前",
    "destroyed" : "已销毁",
    "beforeMount" : "挂载前",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "您已启用两步认证但还没有生成备用码。请确保您进行了这一操作以防您不能访问您的第二因素。"
},
"nplurals=1; plural=0;");
